changeset 16839:daaa2c5bb40a

(sh-shell-file): Downcase and remove extension on shells in NT.
author Richard M. Stallman <rms@gnu.org>
date Tue, 07 Jan 1997 09:02:48 +0000
parents 9bcab3c812bb
children 299b0e0f0a93
files lisp/progmodes/sh-script.el
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/progmodes/sh-script.el	Tue Jan 07 08:14:12 1997 +0000
+++ b/lisp/progmodes/sh-script.el	Tue Jan 07 09:02:48 1997 +0000
@@ -103,10 +103,10 @@
 
 (defvar sh-shell-file
   (or
    ;; On MSDOS, collapse $SHELL to lower-case and remove the
    ;; executable extension, so comparisons with the list of
    ;; known shells work.
-   (and (eq system-type 'ms-dos)
+   (and (memq system-type '(ms-dos windows-nt))
 	(file-name-sans-extension (downcase (getenv "SHELL"))))
    (getenv "SHELL")
    "/bin/sh")
@@ -103,10 +103,10 @@
 (defvar sh-shell-file
   (or
-   ;; On MSDOS, collapse $SHELL to lower-case and remove the
-   ;; executable extension, so comparisons with the list of
+   ;; On MSDOS and Windows, collapse $SHELL to lower-case and remove
+   ;; the executable extension, so comparisons with the list of
    ;; known shells work.